==> humhub-1.11.0-beta.2.tar.gz: humhub-1.11.0-beta.2/protected/humhub/modules/user/messages/pt-BR/account.php <==
<?php

return [
    '<strong>Account</strong> settings' => 'Configurações da Conta',
    '<strong>Confirm</strong></strong> your new email address' => '<strong>Confirme</strong> seu novo endereço de e-mail',
    '<strong>Permissions</strong>' => '<strong> Permissões </strong>',
    '<strong>User</strong> settings' => 'Configurações de <strong>usuário</strong>',
    '<strong>Your</strong> profile' => '<strong>Seu</strong> perfil',
    'All your personal data will be irrevocably deleted.' => 'Todos os seus dados pessoais serão irrevogavelmente excluídos.',
    'Are you sure that you want to delete your account?' => 'Tem certeza de que deseja excluir sua conta?',
    'Changing the username can make some links unusable, for example old links to the profile.' => 'Alterar o nome de usuário pode tornar alguns links inutilizáveis, por exemplo, links antigos para o perfil.',
    'Confirm' => 'Confirmar',
    'Current password' => 'Senha atual',
    'Delete account' => 'Conta excluída',
    'Do you really want to delete your icon image?' => 'Deseja realmente excluir sua imagem de ícone?',
    'Do you really want to delete your logo image?' => 'Você realmente quer apagar sua imagem do logotipo?',
    'E-Mail' => 'E-mail',
    'E-Mail change' => 'Mudança de e-mail',
    'Enter your password to continue' => 'Digite sua senha para continuar',
    'Hello' => 'Olá',
    'Here you can edit your general profile data, which is visible in the about page of your profile.' => 'Aqui você pode editar seus dados gerais de perfil, que estão visíveis na página sobre do seu perfil.',
    'Hide introduction tour panel on dashboard' => 'Ocultar painel de turismo de introdução no painel',
    'Invalid link! Please make sure that you entered the entire url.' => 'Link inválido! Certifique-se de que você digitou a URL inteira.',
    'Language' => 'Idioma',
    'Modules' => 'Módulos',
    'New E-Mail address' => 'Novo endereço de e-mail',
    'New User name' => 'Novo usuário',
    'Not registered users' => 'Usuários não registrados',
    'Notifications' => 'Notificações',
    'Other users' => 'Outros usuários',
    'Password Recovery' => 'Recuperação de senha',
    'Permissions' => 'Permissões',
    'Profile' => 'Perfil',
    'Profile visibility' => 'Visibilidade do perfil',
    'Registered users only' => 'Somente usuários registrados',
    'Save' => 'Salvar',
    'Save profile' => 'Salvar perfil',
    'Settings' => 'Configurações',
    'Tags' => 'Tags',
    'The entered e-mail address is already in use by another user.' => 'O endereço de e-mail inserido já está em uso por outro usuário.',
    'These settings allow you to determine which permissions you want to grant visitors of your own individual profile. Each user can freely adjust the settings for his or her own profile.' => 'Essas configurações permitem que você determine quais permissões deseja conceder aos visitantes de seu próprio perfil individual. Cada usuário pode ajustar livremente as configurações de seu próprio perfil.',
    'TimeZone' => 'Fuso horário',
    'Username has been changed' => 'O nome de usuário foi alterado',
    'Users' => 'Usuários',
    'Visible for all (also unregistered users)' => 'Visível para todos (usuários não registrados também)',
    'We´ve just sent an confirmation e-mail to your new address. <br /> Please follow the instructions inside.' => 'Acabamos de enviar um e-mail de confirmação para o seu novo endereço. <br> Siga as instruções contida nele.',
    'You are currently the owner of following spaces:' => 'Você é atualmente o proprietário dos seguintes espaços:',
    'You have requested to change your e-mail address.<br>Your new e-mail address is {newemail}.<br><br>To confirm your new e-mail address please click on the button below.' => 'Você solicitou a alteração do seu endereço de e-mail.<br>Seu novo endereço de e-mail é {newemail}.<br><br>Para confirmar o seu novo endereço de e-mail, clique no botão abaixo.',
    'You have successfully changed your username.<br>Your new username is {newUsername}.' => 'Você alterou com sucesso o seu nome de usuário. <br> Seu novo nome de usuário é {newUsername}.',
    'You must transfer ownership or delete these spaces before you can delete your account.' => 'Você deve transferir a propriedade ou excluir esses espaços antes de poder excluir sua conta.',
    'Your account cannot be deleted!' => 'Sua conta não pode ser excluída!',
    'Your current E-mail address is <b>{email}</b>. You can change your current E-mail address here.' => 'Seu endereço de e-mail atual é <b>{email}</b>. Você pode alterar seu endereço de e-mail atual aqui.',
    'Your current password can be changed here.' => 'Sua senha atual pode ser alterada aqui.',
    'Your current username is <b>{username}</b>. You can change your current username here.' => 'Seu nome de usuário atual é <b> {username} </b>. Você pode alterar seu nome de usuário atual aqui.',
    'Your e-mail address has been successfully changed to {email}.' => 'Seu e-mail foi alterado com sucesso para {email}.',
    'Your friends' => 'Seus amigos',
    'Your password has been successfully changed!' => 'Sua senha foi alterada com sucesso!',
    'Your username has been changed' => 'Seu nome de usuário foi alterado',
    'Your username has been successfully changed. <br> We´ve just sent an e-mail to you with new information.' => 'Seu nome de usuário foi alterado com sucesso. <br> Acabamos de enviar um e-mail para você com novas informações.',
    '{attribute} "{value}" was not found!' => '{attribute} "{value}" não foi encontrado!',
    'Blocked users' => '',
    'You cannot use this username.' => '',
];

==> humhub-1.17.0-beta.2.tar.gz: humhub-1.17.0-beta.2/protected/humhub/modules/user/messages/pt-BR/account.php <==
<?php

return [
    '<strong>Account</strong> Settings' => 'Configurações de <strong>Conta</strong>',
    '<strong>Confirm</strong></strong> your new email address' => '<strong>Confirme</strong> seu novo endereço de e-mail',
    '<strong>Permissions</strong>' => '<strong>Permissões</strong>',
    '<strong>Your</strong> Account' => '<strong>Sua</strong> conta',
    '<strong>Your</strong> profile' => '<strong>Seu</strong> perfil',
    'Add tags to your profile describing you and highlighting your skills and interests. Your tags will be displayed in your profile and in the \'People\' directory.' => 'Adicione tags ao seu perfil descrevendo você e destacando suas habilidades e interesses. Suas tags serão exibidas em seu perfil e no diretório \'Pessoas\'.',
    'All your personal data will be irrevocably deleted.' => 'Todos os seus dados pessoais serão irrevogavelmente excluídos.',
    'Are you sure that you want to delete your account?' => 'Tem certeza de que deseja excluir sua conta?',
    'Blocked users' => 'Usuários bloqueados',
    'Changing the username can make some links unusable, for example old links to the profile.' => 'Alterar o nome de usuário pode tornar alguns links inutilizáveis, por exemplo, links antigos para o perfil.',
    'Confirm' => 'Confirmar',
    'Current password' => 'Senha atual',
    'Define basic settings for your profile. You can add tags that fit you, choose the language and your time zone and block impolite users.' => 'Defina as configurações básicas para o seu perfil. Você pode adicionar tags adequadas a você, escolher o idioma e seu fuso horário e bloquear usuários indelicados.',
    'Delete account' => 'Excluir conta',
    'Do you really want to delete your icon image?' => 'Deseja realmente excluir sua imagem de ícone?',
    'Do you really want to delete your logo image?' => 'Você realmente quer apagar sua imagem do logotipo?',
    'E-Mail' => 'E-mail',
    'E-Mail change' => 'Mudança de e-mail',
    'Enter your password to continue' => 'Digite sua senha para continuar',
    'General' => 'Geral',
    'Hello' => 'Olá',
    'Here you can edit your general profile data, which is visible in the about page of your profile.' => 'Aqui você pode editar seus dados gerais de perfil, que estão visíveis na página sobre do seu perfil.',
    'Hide introduction tour panel on dashboard' => 'Ocultar painel de introdução do tour no painel',
    'Hide my online status' => 'Ocultar meu status online',
    'Invalid link! Please make sure that you entered the entire url.' => 'Link inválido! Certifique-se de que você digitou a URL inteira.',
    'Language' => 'Idioma',
    'Markdown Editor Mode' => 'Modo de editor Markdown',
    'Modules' => 'Módulos',
    'New E-Mail address' => 'Novo endereço de e-mail',
    'New User name' => 'Novo usuário',
    'Not registered users' => 'Usuários não registrados',
    'Notifications' => 'Notificações',
    'Other users' => 'Outros usuários',
    'Password Recovery' => 'Recuperação de senha',
    'Permissions' => 'Permissões',
    'Plain' => 'Simples',
    'Profile' => 'Perfil',
    'Profile Tags' => 'Tags de perfil',
    'Profile visibility' => 'Visibilidade do perfil',
    'Registered users only' => 'Somente usuários registrados',
    'Rich Text' => 'Rich Text',
    'Save' => 'Salvar',
    'Save profile' => 'Salvar perfil',
    'The entered e-mail address is already in use by another user.' => 'O endereço de e-mail inserido já está em uso por outro usuário.',
    'These settings allow you to determine which permissions you want to grant visitors of your own individual profile. Each user can freely adjust the settings for his or her own profile.' => 'Essas configurações permitem que você determine quais permissões deseja conceder aos visitantes de seu próprio perfil individual. Cada usuário pode ajustar livremente as configurações de seu próprio perfil.',
    'TimeZone' => 'Fuso horário',
    'Username has been changed' => 'O nome de usuário foi alterado',
    'Users' => 'Usuários',
    'Visible for all (also unregistered users)' => 'Visível para todos (usuários não registrados também)',
    'We´ve just sent an confirmation e-mail to your new address. <br /> Please follow the instructions inside.' => 'Acabamos de enviar um e-mail de confirmação para o seu novo endereço. <br> Siga as instruções contida nele.',
    'You are currently the owner of following spaces:' => 'Você é atualmente o proprietário dos seguintes espaços:',
    'You cannot use this username.' => 'Você não pode usar este nome de usuário.',
    'You have requested to change your e-mail address.<br>Your new e-mail address is {newemail}.<br><br>To confirm your new e-mail address please click on the button below.' => 'Você solicitou a alteração do seu endereço de e-mail.<br>Seu novo endereço de e-mail é {newemail}.<br><br>Para confirmar o seu novo endereço de e-mail, clique no botão abaixo.',
    'You have successfully changed your username.<br>Your new username is {newUsername}.' => 'Você alterou com sucesso o seu nome de usuário. <br> Seu novo nome de usuário é {newUsername}.',
    'You must transfer ownership or delete these spaces before you can delete your account.' => 'Você deve transferir a propriedade ou excluir esses espaços antes de poder excluir sua conta.',
    'Your account cannot be deleted!' => 'Sua conta não pode ser excluída!',
    'Your current E-mail address is <b>{email}</b>. You can change your current E-mail address here.' => 'Seu endereço de e-mail atual é <b>{email}</b>. Você pode alterar seu endereço de e-mail atual aqui.',
    'Your current password can be changed here.' => 'Sua senha atual pode ser alterada aqui.',
    'Your current username is <b>{username}</b>. You can change your current username here.' => 'Seu nome de usuário atual é <b> {username} </b>. Você pode alterar seu nome de usuário atual aqui.',
    'Your e-mail address has been successfully changed to {email}.' => 'Seu e-mail foi alterado com sucesso para {email}.',
    'Your friends' => 'Seus amigos',
    'Your password has been successfully changed!' => 'Sua senha foi alterada com sucesso!',
    'Your username has been changed' => 'Seu nome de usuário foi alterado',
    'Your username has been successfully changed. <br> We´ve just sent an e-mail to you with new information.' => 'Seu nome de usuário foi alterado com sucesso. <br> Acabamos de enviar um e-mail para você com novas informações.',
    'Password recovery can only be initiated once every 10 minutes.' => '',
    'Password recovery disabled. Please contact your system administrator.' => '',
];
